@@ -32,6 +32,8 @@ if settings.ADREST_ACCESSLOG:
     class AccessAdmin(admin.ModelAdmin):
         list_display = 'status_code', 'uri', 'method', 'identifier', 'created_at'
         list_filter = 'method',
+        search_fields = 'uri', 'identifier'
+        date_hierarchy = 'created_at'
     admin.site.register(Access, AccessAdmin)
 
     def save_log(sender, response=None, **kwargs):
@@ -45,7 +47,7 @@ if settings.ADREST_ACCESSLOG:
             status_code = response.status_code,
             request = '%s\n\n%s' % ( str(sender.request.META), str(getattr(sender.request, 'data', '')) ),
             identifier = sender.identifier or '',
-            response = response.content[:5000],
+            response = response.content[:5000].rsplit(None, 2)[0],
         )
 
     api_request_finished.connect(save_log)
@@ -76,7 +78,10 @@ if 'django.contrib.auth' in settings.INSTALLED_APPS:
             self.key = self.key or str(uuid.uuid4()).replace('-', '')
             super(AccessKey, self).save(**kwargs)
 
-    admin.site.register(AccessKey)
+    class AccessKeyAdmin(admin.ModelAdmin):
+        list_display = 'key', 'user', 'created'
+        search_fields = 'key', 'identifier', 'user'
+    admin.site.register(AccessKey, AccessKeyAdmin)
 
     # Auto create key for created user
     def create_api_key(sender, created=False, instance=None, **kwargs):
