@@ -11,3 +11,6 @@ DEBUG = getattr(settings, 'ADREST_DEBUG', False)
 # Limit request number per second from same identifier, null is not limited
 THROTTLE_AT = getattr(settings, 'ADREST_THROTTLE_AT', 120)
 THROTTLE_TIMEFRAME = getattr(settings, 'ADREST_THROTTLE_TIMEFRAME', 60)
+
+# We do not restrict access for OPTIONS request.
+AUTHENTICATE_OPTIONS_REQUEST = getattr(settings, 'ADREST_AUTHENTICATE_OPTIONS_REQUEST ', False)
